@@ -1,3 +1,4 @@
+import copy
 import glob
 import importlib
 import inspect
@@ -5,6 +6,7 @@ import os
 import warnings
 from contextlib import contextmanager
 from contextlib import suppress
+from pathlib import Path
 
 from dynaconf import default_settings
 from dynaconf.loaders import default_loader
@@ -30,6 +32,7 @@ from dynaconf.utils.parse_conf import get_converter
 from dynaconf.utils.parse_conf import parse_conf_data
 from dynaconf.utils.parse_conf import true_values
 from dynaconf.validator import ValidatorList
+from dynaconf.vendor.box.box_list import BoxList
 
 
 class LazySettings(LazyObject):
@@ -89,10 +92,11 @@ class LazySettings(LazyObject):
     and all values in a hash called DYNACONF_PROJ in redis
     """
 
-    def __init__(self, **kwargs):
+    def __init__(self, wrapped=None, **kwargs):
         """
         handle initialization for the customization cases
 
+        :param wrapped: a deepcopy of this object will be wrapped (issue #596)
         :param kwargs: values that overrides default_settings
         """
 
@@ -105,6 +109,13 @@ class LazySettings(LazyObject):
         self._kwargs = kwargs
         super(LazySettings, self).__init__()
 
+        if wrapped:
+            if self._django_override:
+                # This fixes django issue #596
+                self._wrapped = copy.deepcopy(wrapped)
+            else:
+                self._wrapped = wrapped
+
     def __resolve_config_aliases(self, kwargs):
         """takes aliases for _FOR_DYNACONF configurations
 
@@ -114,6 +125,8 @@ class LazySettings(LazyObject):
         mispells = {
             "settings_files": "settings_file",
             "SETTINGS_FILES": "SETTINGS_FILE",
+            "environment": "environments",
+            "ENVIRONMENT": "ENVIRONMENTS",
         }
         for mispell, correct in mispells.items():
             if mispell in kwargs:
@@ -121,7 +134,7 @@ class LazySettings(LazyObject):
 
         for_dynaconf_keys = {
             key
-            for key in dir(default_settings)
+            for key in UPPER_DEFAULT_SETTINGS
             if key.endswith("_FOR_DYNACONF")
         }
         aliases = {
@@ -158,7 +171,7 @@ class LazySettings(LazyObject):
                 self._wrapped._fresh
                 or name in self._wrapped.FRESH_VARS_FOR_DYNACONF
             )
-            and name not in dir(default_settings)
+            and name not in UPPER_DEFAULT_SETTINGS
         ):
             return self._wrapped.get_fresh(name)
         value = getattr(self._wrapped, name)
@@ -221,6 +234,7 @@ class Settings:
     """
 
     dynaconf_banner = BANNER
+    _store = DynaBox()
 
     def __init__(self, settings_module=None, **kwargs):  # pragma: no cover
         """Execute loaders and custom initialization
@@ -277,9 +291,25 @@ class Settings:
             super(Settings, self).__delattr__(name)
 
     def __contains__(self, item):
-        "Respond to `item in settings`"
+        """Respond to `item in settings`"""
         return item.upper() in self.store or item.lower() in self.store
 
+    def __getattribute__(self, name):
+        if name not in RESERVED_ATTRS and name not in UPPER_DEFAULT_SETTINGS:
+            with suppress(KeyError):
+                # self._store has Lazy values already evaluated
+                if (
+                    name.islower()
+                    and self._store.get("LOWERCASE_READ_FOR_DYNACONF", empty)
+                    is False
+                ):
+                    # only matches exact casing, first levels always upper
+                    return self._store.to_dict()[name]
+                # perform lookups for upper, and casefold
+                return self._store[name]
+        # in case of RESERVED_ATTRS or KeyError above, keep default behaviour
+        return super().__getattribute__(name)
+
     def __getitem__(self, item):
         """Allow getting variables as dict keys `settings['KEY']`"""
         value = self.get(item, default=empty)
@@ -345,13 +375,15 @@ class Settings:
             data = self.store.to_dict().copy()
             # if not internal remove internal settings
             if not internal:
-                for name in dir(default_settings):
+                for name in UPPER_DEFAULT_SETTINGS:
                     data.pop(name, None)
             return data
 
     to_dict = as_dict  # backwards compatibility
 
-    def _dotted_get(self, dotted_key, default=None, parent=None, **kwargs):
+    def _dotted_get(
+        self, dotted_key, default=None, parent=None, cast=None, **kwargs
+    ):
         """
         Perform dotted key lookups and keep track of where we are.
         :param key: The name of the setting value, will always be upper case
@@ -364,11 +396,15 @@ class Settings:
 
         # If we've reached the end, or parent key not found, then return result
         if not keys or result == default:
+            if cast and cast in converters:
+                return get_converter(cast, result, box_settings=self)
+            elif cast is True:
+                return parse_conf_data(result, tomlfy=True, box_settings=self)
             return result
 
         # If we've still got key elements to traverse, let's do that.
         return self._dotted_get(
-            ".".join(keys), default=default, parent=result, **kwargs
+            ".".join(keys), default=default, parent=result, cast=cast, **kwargs
         )
 
     def get(
@@ -394,6 +430,10 @@ class Settings:
         :param parent: Is there a pre-loaded parent in a nested data?
         :return: The value if found, default or None
         """
+        nested_sep = self._store.get("NESTED_SEPARATOR_FOR_DYNACONF")
+        if nested_sep and nested_sep in key:
+            # turn FOO__bar__ZAZ in `FOO.bar.ZAZ`
+            key = key.replace(nested_sep, ".")
 
         if "." in key and dotted_lookup:
             return self._dotted_get(
@@ -404,6 +444,13 @@ class Settings:
                 parent=parent,
             )
 
+        if default is not None:
+            # default values should behave exactly Dynaconf parsed values
+            if isinstance(default, list):
+                default = BoxList(default)
+            elif isinstance(default, dict):
+                default = DynaBox(default)
+
         key = upperfy(key)
         if key in self._deleted:
             return default
@@ -412,7 +459,7 @@ class Settings:
             fresh
             or self._fresh
             or key in getattr(self, "FRESH_VARS_FOR_DYNACONF", ())
-        ) and key not in dir(default_settings):
+        ) and key not in UPPER_DEFAULT_SETTINGS:
             self.unset(key)
             self.execute_loaders(key=key)
 
@@ -458,7 +505,7 @@ class Settings:
         if data:
             if cast in converters:
                 data = get_converter(cast, data, box_settings=self)
-            if cast is True:
+            elif cast is True:
                 data = parse_conf_data(data, tomlfy=True, box_settings=self)
         return data
 
@@ -536,8 +583,8 @@ class Settings:
 
         new_data = {
             key: self.get(key)
-            for key in dir(default_settings)
-            if key.isupper() and key not in RENAMED_VARS
+            for key in UPPER_DEFAULT_SETTINGS
+            if key not in RENAMED_VARS
         }
 
         # This is here for backwards compatibility
@@ -720,7 +767,7 @@ class Settings:
         """
         key = upperfy(key.strip())
         if (
-            key not in dir(default_settings)
+            key not in UPPER_DEFAULT_SETTINGS
             and key not in self._defaults
             or force
         ):
@@ -920,37 +967,45 @@ class Settings:
             return []
 
         if not self._loaders:
-            for loader_module_name in self.LOADERS_FOR_DYNACONF:
-                loader = importlib.import_module(loader_module_name)
-                self._loaders.append(loader)
+            self._loaders = self.LOADERS_FOR_DYNACONF
 
-        return self._loaders
+        return [importlib.import_module(loader) for loader in self._loaders]
 
     def reload(self, env=None, silent=None):  # pragma: no cover
         """Clean end Execute all loaders"""
         self.clean()
         self.execute_loaders(env, silent)
 
-    def execute_loaders(self, env=None, silent=None, key=None, filename=None):
+    def execute_loaders(
+        self, env=None, silent=None, key=None, filename=None, loaders=None
+    ):
         """Execute all internal and registered loaders
 
         :param env: The environment to load
         :param silent: If loading erros is silenced
         :param key: if provided load a single key
         :param filename: optional custom filename to load
+        :param loaders: optional list of loader modules
         """
         if key is None:
             default_loader(self, self._defaults)
+
         env = (env or self.current_env).upper()
         silent = silent or self.SILENT_ERRORS_FOR_DYNACONF
-        self.pre_load(env, silent=silent, key=key)
-        settings_loader(
-            self, env=env, silent=silent, key=key, filename=filename
-        )
-        self.load_extra_yaml(env, silent, key)  # DEPRECATED
-        enable_external_loaders(self)
-        for loader in self.loaders:
+
+        if loaders is None:
+            self.pre_load(env, silent=silent, key=key)
+            settings_loader(
+                self, env=env, silent=silent, key=key, filename=filename
+            )
+            self.load_extra_yaml(env, silent, key)  # DEPRECATED
+            enable_external_loaders(self)
+
+            loaders = self.loaders
+
+        for loader in loaders:
             loader.load(self, env, silent=silent, key=key)
+
         self.load_includes(env, silent=silent, key=key)
 
     def pre_load(self, env, silent, key):
@@ -991,9 +1046,19 @@ class Settings:
                     # continue the loop.
                     continue
 
-                filepath = os.path.join(
-                    self._root_path or os.getcwd(), _filename
-                )
+                # python 3.6 does not resolve Pathlib basedirs
+                # issue #494
+                root_dir = str(self._root_path or os.getcwd())
+                if (
+                    isinstance(_filename, Path)
+                    and str(_filename.parent) in root_dir
+                ):  # pragma: no cover
+                    filepath = str(_filename)
+                else:
+                    filepath = os.path.join(
+                        self._root_path or os.getcwd(), str(_filename)
+                    )
+
                 paths = [
                     p
                     for p in sorted(glob.glob(filepath))
@@ -1103,14 +1168,27 @@ class Settings:
             if value is not empty:
                 setattr(obj, key, value)
 
-    def dynaconf(self):  # pragma: no cover
+    def dynaconf_clone(self):
+        """Clone the current settings object."""
+        return copy.deepcopy(self)
+
+    @property
+    def dynaconf(self):
         """A proxy to access internal methods and attributes
 
         Starting in 3.0.0 Dynaconf now allows first level lower case
         keys that are not reserved keyword, so this is a proxy to
         internal methods and attrs.
         """
-        return  # TOBE IMPLEMENTED
+
+        class AttrProxy(object):
+            def __init__(self, obj):
+                self.obj = obj
+
+            def __getattr__(self, name):
+                return getattr(self.obj, f"dynaconf_{name}")
+
+        return AttrProxy(self)
 
     @property
     def logger(self):  # pragma: no cover
@@ -1129,6 +1207,9 @@ class Settings:
         return False
 
 
+"""Upper case default settings"""
+UPPER_DEFAULT_SETTINGS = [k for k in dir(default_settings) if k.isupper()]
+
 """Attributes created on Settings before 3.0.0"""
 RESERVED_ATTRS = (
     [
