@@ -1,5 +1,4 @@
 import io
-import os
 import warnings
 
 from dynaconf.utils import build_env_list
@@ -7,7 +6,7 @@ from dynaconf.utils import ensure_a_list
 from dynaconf.utils import upperfy
 
 
-class BaseLoader(object):
+class BaseLoader:
     """Base loader for dynaconf source files.
 
     :param obj: {[LazySettings]} -- [Dynaconf settings]
@@ -60,14 +59,14 @@ class BaseLoader(object):
         else:  # it is already a list/tuple
             files = filename
 
-        source_data = self.get_source_date(files)
+        source_data = self.get_source_data(files)
 
         if self.obj.get("ENVIRONMENTS_FOR_DYNACONF") is False:
             self._envless_load(source_data, silent, key)
         else:
             self._load_all_envs(source_data, silent, key)
 
-    def get_source_date(self, files):
+    def get_source_data(self, files):
         """Reads each file and returns source data for each file
         {"path/to/file.ext": {"key": "value"}}
         """
@@ -100,15 +99,13 @@ class BaseLoader(object):
 
     def _envless_load(self, source_data, silent=True, key=None):
         """Load all the keys from each file without env separation"""
-        for source_file, file_data in source_data.items():
-            self._set_data_to_obj(
-                file_data, self.identifier, source_file, key=key
-            )
+        for file_data in source_data.values():
+            self._set_data_to_obj(file_data, self.identifier, key=key)
 
     def _load_all_envs(self, source_data, silent=True, key=None):
         """Load configs from files separating by each environment"""
 
-        for source_file, file_data in source_data.items():
+        for file_data in source_data.values():
 
             # env name is checked in lower
             file_data = {k.lower(): value for k, value in file_data.items()}
@@ -116,35 +113,18 @@ class BaseLoader(object):
             # is there a `dynaconf_merge` on top level of file?
             file_merge = file_data.get("dynaconf_merge")
 
-            # all lower case for comparison
-            base_envs = [
-                # DYNACONF or MYPROGRAM
-                (self.obj.get("ENVVAR_PREFIX_FOR_DYNACONF") or "").lower(),
-                # DEFAULT
-                self.obj.get("DEFAULT_ENV_FOR_DYNACONF").lower(),
-                # default active env unless ENV_FOR_DYNACONF is changed
-                "development",
-                # backwards compatibility for global
-                "dynaconf",
-                # global that rules all
-                "global",
-            ]
-
             for env in build_env_list(self.obj, self.env):
                 env = env.lower()  # lower for better comparison
                 data = {}
+
                 try:
                     data = file_data[env] or {}
                 except KeyError:
-                    if env not in base_envs:
-                        message = (
-                            f"{self.identifier}_loader: {env} env not"
-                            f"defined in {source_file}"
-                        )
-                        if silent:
-                            warnings.warn(message)
-                        else:
-                            raise KeyError(message)
+                    if silent:
+                        continue
+                    raise
+
+                if not data:
                     continue
 
                 if env != self.obj.get("DEFAULT_ENV_FOR_DYNACONF").lower():
@@ -152,18 +132,14 @@ class BaseLoader(object):
                 else:
                     identifier = self.identifier
 
-                self._set_data_to_obj(
-                    data, identifier, source_file, file_merge, key, env
-                )
+                self._set_data_to_obj(data, identifier, file_merge, key)
 
     def _set_data_to_obj(
         self,
         data,
         identifier,
-        source_file,
         file_merge=None,
         key=False,
-        env=False,
     ):
         """Calls setttings.set to add the keys"""
 
@@ -172,10 +148,6 @@ class BaseLoader(object):
         if key:
             key = upperfy(key)
 
-        is_secret = "secret" in source_file
-        _keys = (list(data.keys()) if is_secret else data,)
-        _path = os.path.split(source_file)[-1]
-
         # is there a `dynaconf_merge` inside an `[env]`?
         file_merge = file_merge or data.pop("DYNACONF_MERGE", False)
 
@@ -183,7 +155,6 @@ class BaseLoader(object):
             self.obj.update(
                 data,
                 loader_identifier=identifier,
-                is_secret=is_secret,
                 merge=file_merge,
             )
         elif key in data:
@@ -191,6 +162,5 @@ class BaseLoader(object):
                 key,
                 data.get(key),
                 loader_identifier=identifier,
-                is_secret=is_secret,
                 merge=file_merge,
             )
